;
; MPFIT_CENT - compute distance of points from centroid
;   P[0] - X position of centroid
;   P[1] - Y position of centroid
;   X - X positions of points
;   Y - Y positions of points
;
function mpfit_cent, p, x_fragment=x, y_fragment=y, $
                     x_station=xs, y_station=ys, radius=radius, $
                     sight_angle=sight_angle

  radius_tolerance = 0.01d    ;; [km] - tolerance in radius measurement
  sight_pos_tolerance = 0.01d ;; [km] - tolerance in sight angle measurement

  resid = [0d]

  ;; MPFIT will automatically square these values, so we need to
  ;; compute only the residual between the point position and the 
  ;; centroid in each direction.
  if n_elements(x) GT 0 then begin
     resid_x = (x-p[0])
     resid_y = (y-p[1])
     
     resid = [resid, resid_x, resid_y]
  endif

  if n_elements(radius) GT 0 then begin
     ;; Radius constraint, distance as measured from station
     resid_r = ((p[0]-xs)^2 + (p[1]-ys)^2 - radius^2)  ;; EQUALS ZERO
     resid = [resid, resid_r / radius_tolerance^2]
  endif

  if n_elements(sight_angle) GT 0 then begin
     resid_s = tan(sight_angle*!dtor)*(p[0]-xs) + ys - p[1] ;; EQUALS ZERO
     resid = [resid, resid_s / sight_pos_tolerance]
  endif

  return, resid
end
